********************************************************************************
*** ARtHEE Phase 1 ESR-Paper
*** Master Do-File
***
*** Steffen Schindler & Felix Bittmann
*** 2021
********************************************************************************


/*DATA
To replicate the results you need access to the NEPS datafiles, which you can
request from the Leibniz Institute for Educational Trajectories (LIFBI), see
https://www.neps-data.de/Mainpage

After you have access, you need to download the correct files for Starting Cohort 6
(Adults) using version 10-0-1 (doi:10.5157/NEPS:SC6:10.0.1). Then you can download
the files in a zipped packaged. Make sure to decompress the package. Since we are
working with Stata, we use the Stata files that are included in this download.
*/

/*ADOS
We use various additional programs that are not part of Stata 16 but are written
by other users. These packages can be installed from the server. To do so, run:

ssc install fre, replace
ssc install blindschemes, replace
ssc install heatplot, replace

*/





clear all
version 16.1
set scheme plotplain		//ADO
********************************************************************************
*** set directories ***
/* For the script to run correctly, you need to set up the folder structure as
shown below.
*/
********************************************************************************
global data    ""
global do      ""
global recoded ""
global output ""


********************************************************************************
*** basic recodes ***
/*First, we need to recode some variables for the purpose of the analyses*/
********************************************************************************
cd "$do"
do basic_recodes.do
********************************************************************************
*** Merge, data cleaning and sample selection ***
/*Next, we need to merge various information together in a single file for
analyses. We also do some data cleaning to sort out cases with missing or
potentially wrong information. Due to the large number of cases, we rely on basic
heuristics to sort out cases with implausible information (for example, people
who have obtained a degree of secondary education at a very young age). Finally
we select the sample for our analyses.
*/
********************************************************************************
cd "$do"
do merge_clean.do
********************************************************************************
*** Analytical sample and descriptive analyses ***
/*Next, we apply some final selection criteria and compute the relevant
statistics. Our main findings are reported in Table 1 in the paper. Due to the
complex nature of this table, it is the result of various separate computations,
which must be copied together manually. These results are of interest since
they are fed in the synthetic simulations afterwards. This means, we do not
rely on the original dataset but test various scenarious using descriptive
results.
*/
********************************************************************************
cd "$do"
keep if inrange(maxegp,1,3)
drop if missing(hzbart) & heeq_c!=1
drop if missing(tertabschluss)
drop if missing(tertstart)

cap drop c
recode byear (1940/1950=0 "1940-50") (1965/1980=1 "1965-80") ///
	(9999=2 "simulation") (else=.), into(c)		

do analyses_description.do		//Deskription
********************************************************************************

/*Finally, we generate the simulations using the Do-Files in the sub-folder "Simulations".
It is important to note that from here on, we do no longer rely on the actual data but
simply work with the descriptives we have computed to far and use this information
to set up simulated scenarios.
*/


cd "$do/Simulation"
do hzb.do               //Higher education eligibility
do hzb_hex.do           //Higher education eligibility
do abschluss.do         //Tertiary education
do abschluss_hex.do     //Tertiary education


*** Manually combine graphs ***
cd "$do/Simulation/Graphs"
graph combine "HZB" "HZB_hex"
graph export "hzb_combined", replace as(png)

graph combine "abschluss" "abschluss_hex"
graph export "abschluss_combined", replace as(png)
