********************************************************************************
*** ARtHEE Phase 1 ESR-Paper
*** Analyses_description.do
***
*** Steffen Schindler & Felix Bittmann
*** 2021
********************************************************************************

cd "$recoded"
use "merged.dta", clear

********************************************************************************
*** recodes and analysis sample ***
********************************************************************************

* sample selection
keep if inrange(maxegp,1,3)
drop if missing(hzbart) & heeq_c!=1
drop if missing(tertabschluss)
drop if missing(tertstart)

*birth cohorts
*Normal*
recode byear (1940/1950=0 "1940-50") (1965/1980=1 "1965-80") ///
	(9999=2 "simulation") (else=.), into(c)		

*Robust*
*recode byear (1940/1952=0 "1940-52") (1965/1980=1 "1965-80") (9999=2 "simulation") (else=.), into(c)


********************************************************************************
*** descriptives ***
********************************************************************************
/*Here we create the tables from the paper. Since these are rather complex, we have
to compute various tables and extract the data manually. Basically, these are rather
simple statistics, like means or proportions for various groups and sub groups.
*/


*local gewicht [aweight=w_t2_cal]			//Auskommentieren, um Gewicht wegzulassen
* ACHTUNG !!! 3.117 Fälle bekommen das Gewicht 0 (wahrscheinlich ALWA-Sample) daher Gewichtung ohne Korrektur des Nullgewichts unbrauchbar!

foreach cohort of numlist 0 1 {
	di "*Panel 1*"
	fre maxegp if c == `cohort' `gewicht', format(1)
		
	di "*Panel 2, Spalte 1*"
	fre hzbart if c == `cohort' `gewicht', format(1)
	
	di "*Panel 2, Spalte 2 / Salariat*"
	fre hzbart if c == `cohort' & maxegp == 3 `gewicht', format(1)
	
	di "*Panel 2, Spalte 3 / Working*"
	fre hzbart if c == `cohort' & maxegp == 1 `gewicht', format(1)
	
	di "*Panel 3, Spalte 1*"
	tab hzbart tertabschluss if c == `cohort', cell
	
	di "*Panel 3, Spalte 2 / Salariat*"
	tab hzbart tertabschluss if c == `cohort' & maxegp == 3, cell
	
	di "*Panel 3, Spalte 3 / Working*"
	tab hzbart tertabschluss if c == `cohort' & maxegp == 1, cell
	
	di "*Letzte Zeile*"
	fre maxegp if c == `cohort' `gewicht'
	di "****************************************************************************"
}


*Konditionaler Studienstart*
foreach class of numlist 1 2 3 {
	tabstat tertstart if maxegp == `class' & c == 1 & hzbart == 1, statistics( mean ) format(%9.3f)
	tabstat tertstart if maxegp == `class' & c == 1 & hzbart == 3, statistics( mean ) format(%9.3f)
	tabstat tertstart if maxegp == `class' & c == 1 & hzbart == 2, statistics( mean )	format(%9.3f)
	di "****************"
	tabstat tertstart if maxegp == `class' & c == 0 & hzbart == 1, statistics( mean ) format(%9.3f)
	tabstat tertstart if maxegp == `class' & c == 0 & hzbart == 3, statistics( mean ) format(%9.3f)
	tabstat tertstart if maxegp == `class' & c == 0 & hzbart == 2, statistics( mean ) format(%9.3f)
	di "************************************************************************"
}


preserve
keep if tertstart == 1
*Konditionaler Studienabschluss*
foreach class of numlist 1 2 3 {
	tabstat tertabschluss if maxegp == `class' & c == 1 & hzbart == 1, statistics( mean ) format(%9.3f)
	tabstat tertabschluss if maxegp == `class' & c == 1 & hzbart == 3, statistics( mean ) format(%9.3f)
	tabstat tertabschluss if maxegp == `class' & c == 1 & hzbart == 2, statistics( mean )	format(%9.3f)
	di "****************"
	tabstat tertabschluss if maxegp == `class' & c == 0 & hzbart == 1, statistics( mean ) format(%9.3f)
	tabstat tertabschluss if maxegp == `class' & c == 0 & hzbart == 3, statistics( mean ) format(%9.3f)
	tabstat tertabschluss if maxegp == `class' & c == 0 & hzbart == 2, statistics( mean ) format(%9.3f)
	di "************************************************************************"
}
restore



*Tabelle 2, Anhang
*Tertstart
bysort maxegp: tabstat tertstart if anyhzb == 1 & c == 1, statistics( mean ) by(hzbart)
by maxegp, sort : tabstat tertstart if anyhzb == 1 & c == 0, statistics( mean ) by(hzbart)

*Tertabschluss
by maxegp, sort : tabstat tertabschluss if tertstart == 1 & c == 1, statistics( mean ) by(hzbart)
by maxegp, sort : tabstat tertabschluss if tertstart == 1 & c == 0, statistics( mean ) by(hzbart)

